local L = AceLibrary("AceLocale-2.2"):new("Comments")


L:RegisterTranslations("enUS", function() return {
	["Comments"] = true,
    ["Description"] = "wowhead.com comments on quest details.",
    
    ["Minimum width"] = true,
    ["Set the minimum width of the comments frame"] = true,
    
    ["Maximum height"] = true,
    ["Set the maximum Height of the comments frame"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Comments"] = "설명",
    ["Description"] = "wowhead.com의 퀘스트 상세 설명을 표시합니다.",
} end)

local moduleName = "Comments"
local Comments = nQuestLog:NewModule(moduleName,"AceEvent-2.0","AceHook-2.1")

local tablet = AceLibrary("Tablet-2.0")
local quixote = AceLibrary("Quixote-1.0")


function Comments:OnModuleLoad()
	self.menuName = L["Comments"]
	self.description = L["Description"]
	
	nQuestLog:RegisterDefaults(moduleName, "profile", {
		["enabled"] = true,
		
		data = {
			fontSizePercent=1.0, detached=true, 
		},

		["minWidth"] = 300,
		["maxHeight"] = 400,
	})
end

function Comments:GetMenu(oldMenu)
	local menu = {
		type="group",
		name=self.menuName,
		order=oldMenu.order,
		desc=self.description,
		args = {
			toggleEnabled = oldMenu,
			
			minWidth = {
				order = oldMenu.order + 1,
				type = "range",
				name = L["Minimum width"],
				desc = L["Set the minimum width of the comments frame"],
				get = function()
					return self.db.profile.minWidth
				end,
				set = function(v)
					self.db.profile.minWidth = v
					tablet:Close('nQuestLog_Comments')
					tablet:Unregister('nQuestLog_Comments')
					self:Update()
				end,
				min=50,
				max=500,
				step=1,
			},
			maxHeight = {
				order = oldMenu.order + 2,
				type = "range",
				name = L["Maximum height"],
				desc = L["Set the maximum Height of the comments frame"],
				get = function()
					return self.db.profile.maxHeight
				end,
				set = function(v)
					self.db.profile.maxHeight = v
					tablet:Close('nQuestLog_Comments')
					tablet:Unregister('nQuestLog_Comments')
					self:Update()
				end,
				min=50,
				max=500,
				step=1,
			},
		}
	}
	return menu
end

function Comments:ToggleEnabled(v)
	self.db.profile.enabled = v
	if (v) then
		self:SecureHook(nQuestLog, "ShowLog")
		if nQuestLog:IsModuleActive('DetailsFrame') then
			self:SecureHook(nQuestLog:GetModule('DetailsFrame'), "UpdateQuestDetail")
		end
	else
		self:Unhook(nQuestLog, "ShowLog")
		if nQuestLog:IsModuleActive('DetailsFrame') then
			self:Unhook(nQuestLog:GetModule('DetailsFrame'), "UpdateQuestDetail")
		end

	end
end

function Comments:ShowLog(object, questid)
	--self.questid = questid
	if questid and LightHeaded and LightHeaded.IterateComments and nQuestLog:IsModuleEnabled("DetailsFrame") then
		self:ScheduleEvent(self.Update, 0, self) --Schedule an event because tablet bugs out otherwise.
	end
end

function Comments:UpdateQuestDetail(object)
	if (LightHeaded and LightHeaded.IterateComments) then
		self:Update()
	end
end


function Comments:GetQuestId()
	local questid
	if nQuestLog:IsModuleEnabled("DetailsFrame") then
		questid =  nQuestLog:GetModule("DetailsFrame").questid
	else
		questid = 1
	end
	
	return questid
end

function Comments:Update()
	-- This is pretty much a copy&paste of Comments.lua in FuBar_QuestsFu, made by kemayo.
	if not tablet:IsRegistered('nQuestLog_Comments') then
		tablet:Register('nQuestLog_Comments', 'detachedData', self.db.profile.data, 'cantAttach', true, 'dontHook', true,
			'hideWhenEmpty', true, 'showTitleWhenDetached', true, 'strata', 'HIGH', 'minWidth', self.db.profile.minWidth, 'maxHeight',self.db.profile.maxHeight,
			'children', function()
				local questid = self:GetQuestId()
				-- Much of this was taken from LightHeaded itself.
				if questid then
					local title, level, tag = quixote:GetQuestById(questid)
					--local color = GetDifficultyColor(level)
					tablet:SetTitle("Comments")
					--tablet:SetTitleColor((color and color.r) or 1, (color and color.g) or 1, (color and color.b) or 1)

					local cat = tablet:AddCategory('text', 'LightHeaded', 'columns', 1, 'wrap', true, 'child_func', LightHeaded.OnHyperlinkClick, 'child_arg1', LightHeaded, 'justify', 'CENTER')

					local anycomments
					for idx, qid, cid, rating, indent, parent, date, poster, comment in LightHeaded:IterateComments(questid) do
						local link = ("comment:%s:%d:%d"):format(title, level, idx)
						
						cat:AddLine('text', ("|cFF66FF66[%s - %s]|r"):format(poster, date), 'arg2', link, 'wrap', true)
						cat:AddLine('text', comment, 'arg2', link, 'wrap', true)
						cat:AddLine('text', ' ', 'func', false) -- spacer.
						
						anycomments = true
					end
					
					if not anycomments then
						cat:AddLine('text', "No comments found...", 'func', false)
						return
					end
				end
			end)
		tablet:Open('nQuestLog_Comments')
	end
	tablet:Refresh('nQuestLog_Comments')
end
